@@ -580,7 +580,7 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_DEPTH_30_ALLOWED),
     MAKE_ENTRY(NV_CTRL_MODE_SET_EVENT),
     MAKE_ENTRY(NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE),
-    MAKE_ENTRY(NV_CTRL_DISPLAYPORT_LINK_RATE),
+    MAKE_ENTRY(NV_CTRL_DISPLAYPORT_LINK_RATE_10MHZ),
     MAKE_ENTRY(NV_CTRL_STEREO_EYES_EXCHANGE),
     MAKE_ENTRY(NV_CTRL_NO_SCANOUT),
     MAKE_ENTRY(NV_CTRL_X_SERVER_UNIQUE_ID),
@@ -623,7 +623,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_READING),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_PROVIDER),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_TARGET),
-    MAKE_ENTRY(NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_MAX_LINK_SPEED),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_RESET_TRANSCEIVER_TO_FACTORY_SETTINGS),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL),
